exclude :test_ary_new, "needs investigation"
exclude :test_aset_error, "needs investigation"
exclude :test_combination_with_callcc, "no callcc"
exclude :test_count, "needs investigation"
exclude :test_flatten_with_callcc, "no callcc"
exclude :test_permutation, "super flaky on travis"
exclude :test_permutation_with_callcc, "no callcc"
exclude :test_product_with_callcc, "no callcc"
exclude :test_reject_with_callcc, "no callcc"
exclude :test_repeated_combination_with_callcc, "no callcc"
exclude :test_repeated_permutation_with_callcc, "no callcc"
exclude :test_rindex2, "needs investigation"
exclude :test_sample_random, "gen2 conc modifies ary"
exclude :test_shuffle_random, "gen conc modifies ary"
exclude :test_sort_bang_with_freeze, ""
exclude :test_sort_with_callcc, "no callcc"
exclude :test_to_h, ""
exclude :test_values_at2, ""
exclude :test_zip, ""
